# Changelog

## Version 0.0.2 - Glorious Green - XXXX-XX-XX

### Enhancements

- TODO

### Changes

- TODO

### Bugfixes

- TODO

## Version 0.0.1 - DISDRODB Birth Date - 2023-01-30

First release of DISDRODB.
